==> plinth_0.13.1+ds.orig.tar.gz: Plinth-0.13.1/README.md <==
[![Build Status](https://travis-ci.org/freedombox/Plinth.svg?branch=master)](https://travis-ci.org/freedombox/Plinth)
[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/shields-badge.svg)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)

# Plinth

[Plinth](https://wiki.debian.org/FreedomBox/Plinth) - a web front end
for administering [FreedomBox](https://freedomboxfoundation.org/)

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=aboutfreedombox.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=tor1.png" width="425px" style="margin: 5px">

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=emailclient.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=newsfeed.png" width="425px" style="margin: 5px">

# Description

FreedomBox is a community project to develop, design and promote
personal servers running free software for private, personal
communications.  It is a networking appliance designed to allow
interfacing with the rest of the Internet under conditions of
protected privacy and data security.  It hosts applications such as
blog, wiki, website, social network, email, web proxy and a Tor relay,
on a device that can replace your Wi-Fi router, so that your data
stays with you.

Plinth is a web interface to administer the functions of the
FreedomBox.  It is extensible and provides various applications of
FreedomBox as modules.  Each module or application provides simplified
user interface to control the underlying functionality.  As FreedomBox
can act as a wireless router, it is possible to configure networking
from Plinth.  Plinth also allows configuration of basic system
parameters such as time zone, hostname and automatic upgrades.

You can find more information about Plinth on the
[Plinth Wiki](https://wiki.debian.org/FreedomBox/Plinth) page,
the [FreedomBox Wiki](https://wiki.debian.org/FreedomBox/) and the
[FreedomBox Manual](https://wiki.debian.org/FreedomBox/Manual).

# Getting Started

See the INSTALL file for additional details and dependencies. To install run:

    $ sudo python3 setup.py install

Run Plinth on the local system with:

    $ sudo plinth

# Contributing

See the HACKING file for contributing to Plinth.

# Localization

[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/287x66-white.png)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)

==> plinth_0.14.0+ds.orig.tar.gz: Plinth-0.14.0/README.md <==
[![Build Status](https://travis-ci.org/freedombox/Plinth.svg?branch=master)](https://travis-ci.org/freedombox/Plinth)
[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/shields-badge.svg)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)
[![Debian Unstable](https://badges.debian.net/badges/debian/unstable/plinth/version.svg)](https://packages.debian.org/unstable/plinth)
[![Debian Testing](https://badges.debian.net/badges/debian/testing/plinth/version.svg)](https://packages.debian.org/testing/plinth)
[![Debian Stable](https://badges.debian.net/badges/debian/stable/plinth/version.svg)](https://packages.debian.org/stable/plinth)

# Plinth

[Plinth](https://wiki.debian.org/FreedomBox/Plinth) - a web front end
for administering [FreedomBox](https://freedomboxfoundation.org/)

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=aboutfreedombox.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=tor1.png" width="425px" style="margin: 5px">

<img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=emailclient.png" width="425px" style="margin: 5px"> <img src="https://wiki.debian.org/FreedomBox/Plinth?action=AttachFile&do=get&target=newsfeed.png" width="425px" style="margin: 5px">

# Description

FreedomBox is a community project to develop, design and promote
personal servers running free software for private, personal
communications.  It is a networking appliance designed to allow
interfacing with the rest of the Internet under conditions of
protected privacy and data security.  It hosts applications such as
blog, wiki, website, social network, email, web proxy and a Tor relay,
on a device that can replace your Wi-Fi router, so that your data
stays with you.

Plinth is a web interface to administer the functions of the
FreedomBox.  It is extensible and provides various applications of
FreedomBox as modules.  Each module or application provides simplified
user interface to control the underlying functionality.  As FreedomBox
can act as a wireless router, it is possible to configure networking
from Plinth.  Plinth also allows configuration of basic system
parameters such as time zone, hostname and automatic upgrades.

You can find more information about Plinth on the
[Plinth Wiki](https://wiki.debian.org/FreedomBox/Plinth) page,
the [FreedomBox Wiki](https://wiki.debian.org/FreedomBox/) and the
[FreedomBox Manual](https://wiki.debian.org/FreedomBox/Manual).

# Getting Started

See the INSTALL file for additional details and dependencies. To install run:

    $ sudo python3 setup.py install

Run Plinth on the local system with:

    $ sudo plinth

# Contributing

See the HACKING file for contributing to Plinth.

# Localization

[![Translation status](https://hosted.weblate.org/widgets/freedombox/-/287x66-white.png)](https://hosted.weblate.org/engage/freedombox/?utm_source=widget)
